@@ -16,15 +16,21 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.2 2004/08/26 19:51:44 chpe Exp $
+ *  $Id: extension.c,v 1.2.2.1 2004/09/26 16:22:39 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-certificates-extension.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
 
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
+
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
