@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.4 2004/02/22 18:54:33 adamh Exp $
+ *  $Id: extension.c,v 1.4.4.1 2004/09/26 16:22:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,11 +26,15 @@
 
 #include "ephy-error-viewer-extension.h"
 #include "error-viewer.h"
+#include "link-checker.h"
+#include "sgml-validator.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
 
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
+
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
